@@ -22,9 +22,12 @@ authorizations = {
     },
 }
 
+class AuthClass:
+    MODEL = None
 
 
 class Api():
+    AuthClass = None
     app = None
     db = None
     api = None
@@ -38,21 +41,44 @@ class Api():
         self.db = database
         self.flask_bcrypt = Bcrypt()
         self.app_config = app_config
+
+        decorators  = []
+        for decorator in getattr(app_config, "DECORATORS", []):
+            arrmod = decorator.split(".")
+            _func = arrmod[-1]
+            arrmod.pop()
+            mod = importlib.import_module(".".join(arrmod))
+            decorators.append(getattr(mod, _func))
+
         self.api = ApiRestplus(self.app,
-            ui=app_config["DOC_UI"] if "DOC_UI" in app_config else True,
+            ui=app_config.DOC_UI if getattr(app_config, "DOC_UI", None) != None else True,
+            doc="/" if getattr(app_config, "DOC_UI", None) != None and getattr(app_config, "DOC_UI", None)  else False,
+            specs=app_config.DOC_UI if getattr(app_config, "DOC_UI", None) != None else True,
             security='Basic Auth',
             authorizations=authorizations,
             title='FLASK RESTPLUS API BOILER-PLATE WITH JWT',
             version='1.0',
             description='a boilerplate for flask restplus web service',
-            format_checker=FormatChecker(formats=["date"])
+            format_checker=FormatChecker(formats=["date"]),
+            decorators=decorators
         )
-        for mod in app_config["ROUTES"]:
+
+        auth_model = getattr(app_config, "AUTH_MODEL", None)
+        if auth_model != None:
+            arrmod = auth_model.split(".")
+            _class = arrmod[-1]
+            arrmod.pop()
+            mod = importlib.import_module(".".join(arrmod))
+            AuthClass.MODEL = getattr(mod, _class)
+            #print(AuthClass.MODEL)
+
+        for mod in getattr(app_config, "ROUTES", []):
             #full_module_name = "app.controller." + mod["controller"]
             #print(full_module_name)
-            #mymodule = importlib.import_module(full_module_name)
+            mymodule = importlib.import_module(mod["module"])
             #print(mymodule)
-            self.api.add_namespace(mod["controller"].api,path=mod["path"])
+            controller = getattr(mymodule, mod["controller"])
+            self.api.add_namespace(controller.api,path=mod["path"])
 
     
     def create_app(self, config_name="dev"):
@@ -60,8 +86,8 @@ class Api():
         CORS(self.app, supports_credentials=True, 
             #origins=["http://localhost:3000", "https://www.micasaldm.mx","http://192.168.0.12:3000","https://tec.apoyoestudiantil.mx", "http://tec.apoyoestudiantil.mx" ]
         )
-        config = self.app_config[config_name]
-        self.app.config.from_object(self.app_config[config_name])
+        config = self.app_config
+        self.app.config.from_object(self.app_config)
 
         self.db.init_app(self.app)
         self.flask_bcrypt.init_app(self.app)
