@@ -16,14 +16,14 @@ class FillableMixin:
                 #print(key + " " + data[key])  
 
 class TimestampMixin:
-    created_at = sa.Column(sa.DateTime(), default=datetime.datetime.utcnow())
+    created_at = sa.Column(sa.DateTime(), default=datetime.datetime.now)
     updated_at = sa.Column(sa.DateTime(), onupdate=datetime.datetime.now)
 
 class SoftDeleteMixin:
     deleted_at = sa.Column(sa.DateTime(timezone=True), nullable=True)
 
     def delete(self, deleted_at=None):
-        self.deleted_at = deleted_at or datetime.datetime.utcnow()
+        self.deleted_at = deleted_at or datetime.datetime.now()
 
     def restore(self):
         self.deleted_at = None
