@@ -15,7 +15,7 @@ class ApiManager():
         application.app_context().push()
         manager = Manager(application)
 
-        migrate = Migrate(application, db, directory="./database/migrations")
+        migrate = Migrate(application, db, directory="./database/"+os.getenv('ENV')+"/migrations/")
         manager.add_command('db', MigrateCommand)
 
         with application.app_context():
