@@ -1,9 +1,12 @@
 
 from .session import Session
-from ..api import database as db, flask_bcrypt, config
+from ..api import database as db, flask_bcrypt, config, AuthClass
 
 from flask import request
-class Auth:
+class Auth(db.Model):
+
+    __abstract__ = True
+
     id = db.Column(db.Integer, primary_key=True, autoincrement=True)
     email = db.Column(db.String(255), unique=True, nullable=False)
     password_hash = db.Column(db.String(255), nullable=True )
@@ -24,7 +27,12 @@ class Auth:
     @staticmethod
     def login(email, password, user_type=None):
         try:
-            auth = Auth.query.filter_by(email=email).first()
+            auth = None
+            if  AuthClass.MODEL != None:
+                auth = AuthClass.MODEL.query.filter_by(email=email).first()
+            else:
+                auth = Auth.query.filter_by(email=email).first()
+
             if auth and auth.check_password(password):
                 if not user_type or (user_type and auth.user_type == user_type):
                     session = Session.open()
@@ -34,6 +42,7 @@ class Auth:
             else:
                 return False
         except Exception as e:
+            print(e)
             return None
     
     @staticmethod
